@@ -5,8 +5,8 @@ import time
 
 from . import (getAllFileList, getFileBaseName, getPath, hold, makeFolder,
                readFile, remove, writeFile)
-from .log import (countLogCritical, countLogError, countLogWarning, error,
-                  info, initLogger, warning)
+
+from .log import error, info, initLogger, warning, getCountCritical, getCountError, getCountWarning
 from .print import (BACKGROUND_DARKGREEN, BACKGROUND_DARKPINK,
                     BACKGROUND_DARKRED, BACKGROUND_DARKYELLOW,
                     FOREGROUND_BLACK, FOREGROUND_DARKRED, FOREGROUND_WHITE,
@@ -23,30 +23,29 @@ def initTask(exeWorkspace, devWorkspace, devTaskList):
     else:
         _workspacePath = getPath(exeWorkspace)
         _runTaskFile(sys.argv[-1])
+    if not _isDev():
+        while True:
+            time.sleep(1)
 
 
-def getPathByWorkspace(*parList):
+def getPathByWorkspace(*parList) -> str:
     return getPath(_workspacePath, *parList)
 
 
 def runTask(moduleName, **parDict):
     exec(f"import {moduleName}")
     module = eval(moduleName)
-    try:
-        for k, v in parDict.items():
-            if hasattr(module, k):
-                setattr(module, k, v)
-            else:
-                warning(f"模块缺少属性定义 module={moduleName} k={k} v={v}")
-        module.run()
-    except Exception as e:
-        raise e
-    finally:
-        if hasattr(module, "clean"):
-            module.clean()
+    for k, v in parDict.items():
+        if hasattr(module, k):
+            setattr(module, k, v)
+        else:
+            warning(f"模块缺少属性定义 module={moduleName} k={k} v={v}")
+    module.run()
+    if hasattr(module, "clean"):
+        module.clean()
 
 
-def _isDev():
+def _isDev() -> bool:
     return sys.executable.endswith("python.exe")
 
 
@@ -122,11 +121,11 @@ def _runTaskList(taskList):
         error("执行失败")
     finally:
 
-        if countLogCritical:
+        if getCountCritical():
             color = FOREGROUND_WHITE | BACKGROUND_DARKPINK
-        elif countLogError:
+        elif getCountError():
             color = FOREGROUND_WHITE | BACKGROUND_DARKRED
-        elif countLogWarning:
+        elif getCountWarning():
             color = FOREGROUND_BLACK | BACKGROUND_DARKYELLOW
         else:
             color = FOREGROUND_BLACK | BACKGROUND_DARKGREEN
@@ -135,12 +134,12 @@ def _runTaskList(taskList):
         info("---------------------------------------------------------------------------")
 
         msgAry = ["任务结束"]
-        if countLogCritical:
-            msgAry.append(f"critical({countLogCritical})")
-        if countLogError:
-            msgAry.append(f"error({countLogError})")
-        if countLogWarning:
-            msgAry.append(f"warning({countLogWarning})")
+        if getCountCritical():
+            msgAry.append(f"critical({getCountCritical()})")
+        if getCountError():
+            msgAry.append(f"error({getCountError()})")
+        if getCountWarning():
+            msgAry.append(f"warning({getCountWarning()})")
 
         setPrintColor(color)
         info(" ".join(msgAry))
@@ -148,12 +147,9 @@ def _runTaskList(taskList):
         passTime = str(datetime.datetime.now() - startTime)
         if passTime.startswith("0:"):
             passTime = "0" + passTime
-            
+
         setPrintColor(color)
         info(f"用时：{passTime}")
-        
+
         resetPrintColor()
         remove(lockFile)
-        if not _isDev():
-            while True:
-                time.sleep(1)
